import { FC } from 'react';
interface BraceHeadProps {
    results_length: number;
    headers: string[];
}
declare const BraceHead: FC<BraceHeadProps>;
export { BraceHead };
//# sourceMappingURL=Head.d.ts.map