import { FC } from 'react';
import './style/isintersectingform.scss';
interface IsIntersectingFormProps {
    children: any;
}
declare const IsIntersectingForm: FC<IsIntersectingFormProps>;
export { IsIntersectingForm };
//# sourceMappingURL=IsIntersectingForm.d.ts.map