import { FC } from 'react';
import { FieldProps } from '.';
import { CharFieldModel } from 'state';
declare type TChar = FC<FieldProps<CharFieldModel>>;
declare const CharField: TChar;
export { CharField };
//# sourceMappingURL=text.d.ts.map