import { FC } from 'react';
import { PageModel } from 'state';
import './style/paginator.scss';
declare const Paginator: FC<PageModel>;
export default Paginator;
//# sourceMappingURL=Paginator.d.ts.map