declare const BraceInfoAtom: import("jotai").WritableAtom<Promise<import("../../models/BraceList").BL_InfoModel | "loading">, string, Promise<void>>;
export { BraceInfoAtom };
//# sourceMappingURL=info.d.ts.map