import { FC } from 'react';
import './style/searchinput.scss';
interface SearchInputProps {
    submit: (search_text: string) => void;
}
declare const SearchInput: FC<SearchInputProps>;
export { SearchInput };
//# sourceMappingURL=SearchInput.d.ts.map