interface UserModel {
    username: string;
    avatar: string;
    email: string;
    first_name: string;
    last_name: string;
}
declare const DefaultUser: UserModel;
export { UserModel, DefaultUser };
//# sourceMappingURL=User.d.ts.map