{% load static %}

<!DOCTYPE html>
<html lang="en">
    <head>
        <script>
            var BASE_URL = '{{ base_url }}';
        </script>

        {% comment %} {% include "includes/meta.html" %} {% endcomment %}

         

        {% block head %}{% endblock head %}

        <title>Black Night | {% block title %}{% endblock title %}</title>
    <script defer src="{% static 'black_knight/dist/runtime.d3c77aeac769298a6f85.js' %}"></script><script defer src="{% static 'black_knight/dist/react_vendors.d53fcf6e1a399ff5983c.js' %}"></script><script defer src="{% static 'black_knight/dist/shared.06487c113519a9e8d78e.js' %}"></script><script defer src="{% static 'black_knight/dist/state.640284d102d58a01a221.js' %}"></script><script defer src="{% static 'black_knight/dist/components.d46a5391271aa1062c06.js' %}"></script><script defer src="{% static 'black_knight/dist/main.9ef8bfe518c79924975f.js' %}"></script><script defer src="{% static 'black_knight/dist/Login.6ef159725f42d1ed0804.js' %}"></script><script defer src="{% static 'black_knight/dist/Dashboard.1fd69a091a64d91d70e2.js' %}"></script><link href="{% static 'black_knight/dist/components.css' %}" rel="stylesheet"><link href="{% static 'black_knight/dist/main.css' %}" rel="stylesheet"><link href="{% static 'black_knight/dist/Login.css' %}" rel="stylesheet"><link href="{% static 'black_knight/dist/Dashboard.css' %}" rel="stylesheet"></head>

    <body>
        <div 
            class="root" id="root" 
            role="application" aria-label="application"
            >{% block content %}{% endblock content %}</div>
    </body>
</html>
